@@ -45,8 +45,10 @@ RNs_selected <- RN_index_screen(dk_mode = "SF", min_half_life_seconds = 0.5 * 3.
 knitr::kable(RNs_selected[, c(1:3)])
 
 ## ----echo = TRUE--------------------------------------------------------------
+
 RN_find_parent("Th-230")
 
+
 ## -----------------------------------------------------------------------------
 air_dens_cf(T.actual = 30, P.actual = 760, T.ref = 20, P.ref = 760)
 
@@ -85,6 +87,19 @@ rate_meter_sim(cpm_equilibrium = 270, meter_scale_increments = seq(100, 1000, 20
 ## -----------------------------------------------------------------------------
 stay_time(dose_rate = 120, dose_allowed = 100, margin =  20)
 
+## ----echo = FALSE-------------------------------------------------------------
+mm_Al <- 0:5
+mR_h <- c(7.428, 6.272, 5.325,4.535, 3.878, 3.317)
+
+## ----echo = TRUE--------------------------------------------------------------
+hvl(x = mm_Al, y = mR_h) 
+
+## -----------------------------------------------------------------------------
+mcnp_matrix_rotations("z", 90)
+
+## -----------------------------------------------------------------------------
+mcnp_cone_angle(30)
+
 ## ----echo = FALSE-------------------------------------------------------------
 plot_data <- photons_cs137_hist
 
